@@ -55,7 +55,7 @@ class MatplotlibBackend(Plot):
         * ``'auto'``: Matplotlib will fit the plot in the vibile area.
         * ``"equal"``: sets equal spacing on the axis of a 2D plot.
         * tuple containing 2 float numbers, from which the aspect ratio is
-          computed.
+          computed. This only works for 2D plots.
 
     axis_center : (float, float) or str or None, optional
         Set the location of the intersection between the horizontal and
@@ -81,11 +81,38 @@ class MatplotlibBackend(Plot):
         * Refer to [#fn5]_ to customize quiver plots.
         * Refer to [#fn6]_ to customize surface plots.
         * Refer to [#fn7]_ to customize stramline plots.
+        * Refer to [#fn8]_ to customize 3D scatter plots.
 
     use_cm : boolean, optional
         If True, apply a color map to the mesh/surface or parametric lines.
         If False, solid colors will be used instead. Default to True.
 
+    annotations : list, optional
+        A list of dictionaries specifying the type of annotation
+        required. The keys in the dictionary should be equivalent
+        to the arguments of the `matplotlib.axes.Axes.annotate` method.
+        This feature is experimental. It might get removed in the future.
+
+    markers : list, optional
+        A list of dictionaries specifying the type the markers required.
+        The keys in the dictionary should be equivalent to the arguments
+        of the `matplotlib.pyplot.plot()` function along with the marker
+        related keyworded arguments.
+        This feature is experimental. It might get removed in the future.
+
+    rectangles : list, optional
+        A list of dictionaries specifying the dimensions of the
+        rectangles to be plotted. The keys in the dictionary should be
+        equivalent to the arguments of the `matplotlib.patches.Rectangle`
+        class.
+        This feature is experimental. It might get removed in the future.
+
+    fill : dict, optional
+        A dictionary specifying the type of color filling required in
+        the plot. The keys in the dictionary should be equivalent to the
+        arguments of the `matplotlib.axes.Axes.fill_between` method.
+        This feature is experimental. It might get removed in the future.
+
 
     References
     ==========
@@ -96,6 +123,7 @@ class MatplotlibBackend(Plot):
     .. [#fn5] https://matplotlib.org/stable/api/quiver_api.html#module-matplotlib.quiver
     .. [#fn6] https://matplotlib.org/stable/api/_as_gen/mpl_toolkits.mplot3d.axes3d.Axes3D.html#mpl_toolkits.mplot3d.axes3d.Axes3D.plot_surface
     .. [#fn7] https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.streamplot.html#matplotlib.axes.Axes.streamplot
+    .. [#fn8] https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.scatter.html
 
 
     See also
@@ -105,7 +133,10 @@ class MatplotlibBackend(Plot):
     """
 
     _library = "matplotlib"
+    _allowed_keys = Plot._allowed_keys + [
+        "markers", "annotations", "fill", "rectangles"]
 
+    wireframe_color = "k"
     colormaps = []
     cyclic_colormaps = []
 
@@ -116,12 +147,14 @@ class MatplotlibBackend(Plot):
         self.matplotlib = import_module(
             'matplotlib',
             import_kwargs={'fromlist': ['pyplot', 'cm', 'collections', 'colors']},
+            warn_not_installed=True,
             min_module_version='1.1.0',
             catch=(RuntimeError,))
         self.plt = self.matplotlib.pyplot
         self.cm = cm = self.matplotlib.cm
         self.LineCollection = self.matplotlib.collections.LineCollection
         self.ListedColormap = self.matplotlib.colors.ListedColormap
+        self.Line2D = self.matplotlib.lines.Line2D
         self.Normalize = self.matplotlib.colors.Normalize
 
         # set default colors
@@ -157,6 +190,7 @@ class MatplotlibBackend(Plot):
         self._show_minor_grid = kwargs.get("show_minor_grid", cfg["matplotlib"]["show_minor_grid"])
 
         self._handles = dict()
+        self._legend_handles = []
 
     def _set_piecewise_color(self, s, color):
         """Set the color to the given series"""
@@ -215,11 +249,13 @@ class MatplotlibBackend(Plot):
 
             is_3D = [s.is_3D for s in self.series]
             if any(is_3D) and (not all(is_3D)):
-                raise ValueError(
-                    "The matplotlib backend can not mix 2D and 3D.")
+                # allow sum of 3D plots with contour plots
+                if not all(s.is_3D or s.is_contour for s in self.series):
+                    raise ValueError(
+                        "MatplotlibBackend can not mix 2D and 3D.")
 
             kwargs = dict(aspect=aspect)
-            if all(is_3D):
+            if any(is_3D):
                 kwargs["projection"] = "3d"
             elif any(s.is_2Dline and s.is_polar for s in self.series):
                 kwargs["projection"] = "polar"
@@ -321,6 +357,7 @@ class MatplotlibBackend(Plot):
 
         self.ax.cla()
         self._init_cyclers()
+        self._legend_handles = []
 
         for i, s in enumerate(series):
             kw = None
@@ -333,11 +370,17 @@ class MatplotlibBackend(Plot):
                         if self._use_cyclic_cm(param, s.is_complex)
                         else next(self._cm)
                     )
-                    lkw = dict(array=param, cmap=colormap)
-                    kw = merge({}, lkw, s.rendering_kw)
-                    segments = self.get_segments(x, y)
-                    c = self.LineCollection(segments, **kw)
-                    self.ax.add_collection(c)
+                    if not s.is_point:
+                        lkw = dict(array=param, cmap=colormap)
+                        kw = merge({}, lkw, s.rendering_kw)
+                        segments = self.get_segments(x, y)
+                        c = self.LineCollection(segments, **kw)
+                        self.ax.add_collection(c)
+                    else:
+                        lkw = dict(c=param, cmap=colormap)
+                        kw = merge({}, lkw, s.rendering_kw)
+                        c = self.ax.scatter(x, y, **kw)
+
                     is_cb_added = self._add_colorbar(c, s.get_label(self._use_latex), s.use_cm)
                     self._add_handle(i, c, kw, is_cb_added, self._fig.axes[-1])
                 else:
@@ -370,15 +413,25 @@ class MatplotlibBackend(Plot):
                     # quivers. Setting zorder appears to fix the problem.
                     ckw["zorder"] = 0
                 kw = merge({}, ckw, s.rendering_kw)
-                c = self.ax.contourf(x, y, z, **kw)
-                self._add_colorbar(c, s.get_label(self._use_latex), s.use_cm, True)
-                self._add_handle(i, c, kw, self._fig.axes[-1])
+                func = self.ax.contourf if s.is_filled else self.ax.contour
+                c = func(x, y, z, **kw)
+                clabel = None
+                if s.is_filled:
+                    self._add_colorbar(c, s.get_label(self._use_latex),
+                        s.use_cm, True)
+                else:
+                    clabel = self.ax.clabel(c)
+                self._add_handle(i, c, kw, self._fig.axes[-1], clabel)
 
             elif s.is_3Dline:
-                x, y, z, param = s.get_data()
+                if s.is_parametric:
+                    x, y, z, param = s.get_data()
+                else:
+                    x, y, z = s.get_data()
+                    param = np.ones_like(x)
                 lkw = dict()
 
-                if len(x) > 1:
+                if not s.is_point:
                     if s.use_cm:
                         segments = self.get_segments(x, y, z)
                         lkw["cmap"] = next(self._cm)
@@ -390,15 +443,28 @@ class MatplotlibBackend(Plot):
                         self._add_handle(i, c)
                     else:
                         lkw["label"] = s.get_label(self._use_latex)
-                        kw = merge({}, lkw, s.rendering_kw, {} if s.line_color is None else {"color": s.line_color})
+                        kw = merge({}, lkw, s.rendering_kw,
+                            ({} if s.line_color is None
+                            else {"color": s.line_color}) if s.show_in_legend
+                            else {"color": self.wireframe_color})
                         l = self.ax.plot(x, y, z, **kw)
                         self._add_handle(i, l)
                 else:
-                    # 3D points
-                    lkw["label"] = s.get_label(self._use_latex)
-                    lkw["color"] = next(self._cl) if s.line_color is None else s.line_color
+                    if s.use_cm:
+                        lkw["cmap"] = next(self._cm)
+                        lkw["c"] = param
+                    else:
+                        # lkw["c"] = param
+                        lkw["color"] = next(self._cl) if s.line_color is None else s.line_color
+
+                    if not s.is_filled:
+                        lkw["facecolors"] = "none"
+
+                    lkw["alpha"] = 1
                     kw = merge({}, lkw, s.rendering_kw)
                     l = self.ax.scatter(x, y, z, **kw)
+                    if s.use_cm:
+                        self._add_colorbar(l, s.get_label(self._use_latex), s.use_cm)
                     self._add_handle(i, l)
                 xlims.append((np.amin(x), np.amax(x)))
                 ylims.append((np.amin(y), np.amax(y)))
@@ -414,7 +480,9 @@ class MatplotlibBackend(Plot):
                 skw = dict(rstride=1, cstride=1, linewidth=0.1)
                 norm, cmap = None, None
                 if s.use_cm:
-                    norm = self.Normalize(vmin=np.amin(facecolors), vmax=np.amax(facecolors))
+                    vmin = s.rendering_kw.get("vmin", np.amin(facecolors))
+                    vmax = s.rendering_kw.get("vmax", np.amax(facecolors))
+                    norm = self.Normalize(vmin=vmin, vmax=vmax)
                     cmap = next(self._cm)
                     skw["cmap"] = cmap
                 else:
@@ -440,7 +508,8 @@ class MatplotlibBackend(Plot):
                 if len(points) == 2:
                     # interval math plotting
                     x, y = _matplotlib_list(points[0])
-                    c = self.ax.fill(x, y, color=next(self._cl),
+                    color = next(self._cl)
+                    c = self.ax.fill(x, y, color=color,
                         edgecolor="None")
                     self._add_handle(i, c)
                 else:
@@ -460,16 +529,25 @@ class MatplotlibBackend(Plot):
                         kw = merge({}, ckw, s.rendering_kw)
                         c = self.ax.contourf(xarray, yarray, zarray, **kw)
                     self._add_handle(i, c, kw)
+                proxy_artist = self.Line2D([], [],
+                    color=color, label=s.get_label(self._use_latex))
+                self._legend_handles.append(proxy_artist)
 
             elif s.is_vector:
                 if s.is_2Dvector:
                     xx, yy, uu, vv = s.get_data()
-                    magn = np.sqrt(uu ** 2 + vv ** 2)
+                    mag = np.sqrt(uu ** 2 + vv ** 2)
+                    uu0, vv0 = [t.copy() for t in [uu, vv]]
+                    if s.normalize:
+                        uu, vv = [t / mag for t in [uu, vv]]
                     if s.is_streamlines:
                         skw = dict()
                         if (not s.use_quiver_solid_color) and s.use_cm:
+                            color_val = mag
+                            if s.color_func is not None:
+                                color_val = s.color_func(xx, yy, uu0, vv0)
                             skw["cmap"] = next(self._cm)
-                            skw["color"] = magn
+                            skw["color"] = color_val
                             kw = merge({}, skw, s.rendering_kw)
                             sp = self.ax.streamplot(xx, yy, uu, vv, **kw)
                             is_cb_added = self._add_colorbar(
@@ -498,9 +576,12 @@ class MatplotlibBackend(Plot):
                         if (not s.use_quiver_solid_color) and s.use_cm:
                             # don't use color map if a scalar field is
                             # visible or if use_cm=False
+                            color_val = mag
+                            if s.color_func is not None:
+                                color_val = s.color_func(xx, yy, uu0, vv0)
                             qkw["cmap"] = next(self._cm)
                             kw = merge({}, qkw, s.rendering_kw)
-                            q = self.ax.quiver(xx, yy, uu, vv, magn, **kw)
+                            q = self.ax.quiver(xx, yy, uu, vv, color_val, **kw)
                             is_cb_added = self._add_colorbar(
                                 q, s.get_label(self._use_latex), s.use_cm)
                         else:
@@ -512,11 +593,16 @@ class MatplotlibBackend(Plot):
                             self._fig.axes[-1])
                 else:
                     xx, yy, zz, uu, vv, ww = s.get_data()
-                    magn = np.sqrt(uu ** 2 + vv ** 2 + ww ** 2)
+                    mag = np.sqrt(uu ** 2 + vv ** 2 + ww ** 2)
+
+                    uu0, vv0, zz0 = [t.copy() for t in [uu, vv, ww]]
+                    if s.normalize:
+                        uu, vv, ww = [t / mag for t in [uu, vv, ww]]
 
                     if s.is_streamlines:
-                        vertices, magn = compute_streamtubes(
-                            xx, yy, zz, uu, vv, ww, s.rendering_kw)
+                        vertices, color_val = compute_streamtubes(
+                            xx, yy, zz, uu, vv, ww, s.rendering_kw,
+                            s.color_func)
 
                         lkw = dict()
                         stream_kw = s.rendering_kw.copy()
@@ -529,7 +615,7 @@ class MatplotlibBackend(Plot):
                             segments = self.get_segments(
                                 vertices[:, 0], vertices[:, 1], vertices[:, 2])
                             lkw["cmap"] = next(self._cm)
-                            lkw["array"] = magn
+                            lkw["array"] = color_val
                             kw = merge({}, lkw, stream_kw)
                             c = Line3DCollection(segments, **kw)
                             self.ax.add_collection(c)
@@ -548,8 +634,19 @@ class MatplotlibBackend(Plot):
                     else:
                         qkw = dict()
                         if s.use_cm:
+                            # NOTE: each quiver is composed of 3 lines: the
+                            # stem and two segments for the head. I could set
+                            # the colors keyword argument in order to apply
+                            # the same color to the entire quiver, like this:
+                            # [c1, c2, ..., cn, c1, c1, c2, c2, ... cn, cn]
+                            # However, it doesn't appear to work reliably, so
+                            # I'll keep things simpler.
+                            color_val = mag
+                            if s.color_func is not None:
+                                color_val = s.color_func(
+                                    xx, yy, zz, uu0, vv0, zz0)
                             qkw["cmap"] = next(self._cm)
-                            qkw["array"] = magn.flatten()
+                            qkw["array"] = color_val.flatten()
                             kw = merge({}, qkw, s.rendering_kw)
                             q = self.ax.quiver(xx, yy, zz, uu, vv, ww, **kw)
                             is_cb_added = self._add_colorbar(
@@ -636,6 +733,20 @@ class MatplotlibBackend(Plot):
                 c = self.ax.fill(x, y, **kw)
                 self._add_handle(i, c, kw)
 
+            elif s.is_generic:
+                if s.type == "markers":
+                    kw = merge({}, {"color": next(self._cl)}, s.rendering_kw)
+                    self.ax.plot(*s.args, **kw)
+                elif s.type == "annotations":
+                    self.ax.annotate(*s.args, **s.rendering_kw)
+                elif s.type == "fill":
+                    kw = merge({}, {"color": next(self._cl)}, s.rendering_kw)
+                    self.ax.fill_between(*s.args, **kw)
+                elif s.type == "rectangles":
+                    kw = merge({}, {"color": next(self._cl)}, s.rendering_kw)
+                    self.ax.add_patch(
+                        self.matplotlib.patches.Rectangle(*s.args, **kw))
+
             else:
                 raise NotImplementedError(
                     "{} is not supported by {}\n".format(type(s), type(self).__name__)
@@ -683,23 +794,22 @@ class MatplotlibBackend(Plot):
             if isinstance(self.ax, Axes3D):
                 self.ax.grid()
             else:
-                self.ax.grid(which='major', axis='x', linewidth=0.75,
-                    linestyle='-', color='0.85')
-                self.ax.grid(which='minor', axis='x', linewidth=0.25,
-                    linestyle='--', color='0.80')
-                self.ax.grid(which='major', axis='y', linewidth=0.75,
-                    linestyle='-', color='0.85')
-                self.ax.grid(which='minor', axis='y', linewidth=0.25,
-                    linestyle='--', color='0.80')
+                self.ax.grid(visible=True, which='major', linestyle='-',
+                    linewidth=0.75, color='0.75')
+                self.ax.grid(visible=True, which='minor', linestyle='--',
+                    linewidth=0.6, color='0.825')
                 if self._show_minor_grid:
                     self.ax.minorticks_on()
         if self.legend:
-            handles, _ = self.ax.get_legend_handles_labels()
-            # Show the legend only if there are legend entries. For example,
-            # if we are plotting only parametric expressions, there will be
-            # only colorbars, no legend entries.
-            if len(handles) > 0:
-                self.ax.legend(loc="best")
+            if len(self._legend_handles) > 0:
+                self.ax.legend(handles=self._legend_handles, loc="best")
+            else:
+                handles, _ = self.ax.get_legend_handles_labels()
+                # Show the legend only if there are legend entries.
+                # For example, if we are plotting only parametric expressions,
+                # there will be only colorbars, no legend entries.
+                if len(handles) > 0:
+                    self.ax.legend(loc="best")
         if self.title:
             self.ax.set_title(self.title)
         if self.xlabel:
@@ -715,6 +825,17 @@ class MatplotlibBackend(Plot):
 
         self._set_lims(xlims, ylims, zlims)
 
+    def _get_plotting_func_name(self, t):
+        if t == "markers":
+            return "scatter"
+        elif t == "annotations":
+            return "annotate"
+        elif t == "fills":
+            return "fill"
+        elif t == "rectangles":
+            return "rect"
+        raise ValueError("%s is not supported by MatplotlibBackend" % t)
+
     def _set_lims(self, xlims, ylims, zlims):
         np = import_module('numpy')
         mpl_toolkits = import_module(
@@ -817,10 +938,18 @@ class MatplotlibBackend(Plot):
                 if s.is_2Dline:
                     if s.is_parametric and s.use_cm:
                         x, y, param = self.series[i].get_data()
-                        segments = self.get_segments(x, y)
-                        self._handles[i][0].set_segments(segments)
-                        self._handles[i][0].set_array(param)
                         kw, is_cb_added, cax = self._handles[i][1:]
+
+                        if not s.is_point:
+                            segments = self.get_segments(x, y)
+                            self._handles[i][0].set_segments(segments)
+                            self._handles[i][0].set_array(param)
+                        else:
+                            self._handles[i][0].set_offsets(np.c_[x,y])
+                            self._handles[i][0].set_array(param)
+                            self._handles[i][0].set_clim(
+                                vmin=min(param), vmax=max(param))
+
                         if is_cb_added:
                             norm = self.Normalize(vmin=np.amin(param), vmax=np.amax(param))
                             self._update_colorbar(cax, kw["cmap"], s.get_label(self._use_latex), norm=norm)
@@ -835,7 +964,11 @@ class MatplotlibBackend(Plot):
                         self._handles[i][0].set_data(x, y)
 
                 elif s.is_3Dline:
-                    x, y, z, _ = self.series[i].get_data()
+                    if s.is_parametric:
+                        x, y, z, _ = self.series[i].get_data()
+                    else:
+                        x, y, z = self.series[i].get_data()
+
                     if isinstance(self._handles[i][0], Line3DCollection):
                         # gradient lines
                         segments = self.get_segments(x, y, z)
@@ -844,19 +977,31 @@ class MatplotlibBackend(Plot):
                         # 3D points
                         self._handles[i][0]._offsets3d = (x, y, z)
                     else:
-                        # solid lines
-                        self._handles[i][0].set_data_3d(x, y, z)
+                        if hasattr(self._handles[i][0], "set_data_3d"):
+                            # solid lines
+                            self._handles[i][0].set_data_3d(x, y, z)
+                        else:
+                            # scatter
+                            self._handles[i][0].set_offset(np.c_[x, y, z])
                     xlims.append((np.amin(x), np.amax(x)))
                     ylims.append((np.amin(y), np.amax(y)))
                     zlims.append((np.amin(z), np.amax(z)))
 
                 elif s.is_contour and (not s.is_complex):
                     x, y, z = self.series[i].get_data()
-                    kw, cax = self._handles[i][1:]
+                    kw, cax, clabels = self._handles[i][1:]
                     for c in self._handles[i][0].collections:
                         c.remove()
-                    self._handles[i][0] = self.ax.contourf(x, y, z, **kw)
-                    self._update_colorbar(cax, kw["cmap"], s.get_label(self._use_latex), param=z)
+                    if not s.is_filled:
+                        for cl in clabels:
+                            cl.remove()
+                    func = self.ax.contourf if s.is_filled else self.ax.contour
+                    self._handles[i][0] = func(x, y, z, **kw)
+                    if s.is_filled:
+                        self._update_colorbar(cax, kw["cmap"], s.get_label(self._use_latex), param=z)
+                    else:
+                        clabels = self.ax.clabel(self._handles[i][0])
+                        self._handles[i][-1] = clabels
                     xlims.append((np.amin(x), np.amax(x)))
                     ylims.append((np.amin(y), np.amax(y)))
 
@@ -872,7 +1017,12 @@ class MatplotlibBackend(Plot):
                     kw, is_cb_added, cax = self._handles[i][1:]
 
                     if is_cb_added:
-                        norm = self.Normalize(vmin=np.amin(facecolors), vmax=np.amax(facecolors))
+                        # TODO: if use_cm=True and a single 3D expression is
+                        # shown with legend=False, this won't get executed.
+                        # In widget plots, the surface will never change color.
+                        vmin = s.rendering_kw.get("vmin", np.amin(facecolors))
+                        vmax = s.rendering_kw.get("vmax", np.amax(facecolors))
+                        norm = self.Normalize(vmin=vmin, vmax=vmax)
                         cmap = kw["cmap"]
                         if isinstance(cmap, str):
                             cmap = self.cm.get_cmap(cmap)
@@ -911,19 +1061,32 @@ class MatplotlibBackend(Plot):
 
                     xx, yy, zz, uu, vv, ww = self.series[i].get_data()
                     kw, is_cb_added, cax = self._handles[i][1:]
+                    mag = np.sqrt(uu ** 2 + vv ** 2 + ww ** 2)
+                    uu0, vv0, ww0 = [t.copy() for t in [uu, vv, ww]]
+                    if s.normalize:
+                        uu, vv, ww = [t / mag for t in [uu, vv, ww]]
                     self._handles[i][0].remove()
+
+                    if "array" in kw.keys():
+                        color_val = mag
+                        if s.color_func is not None:
+                            color_val = s.color_func(xx, yy, zz, uu0, vv0, ww0)
+                        kw["array"] = color_val.flatten()
+
                     self._handles[i][0] = self.ax.quiver(xx, yy, zz, uu, vv, ww, **kw)
 
                     if is_cb_added:
-                        magn = np.sqrt(uu ** 2 + vv ** 2 + ww ** 2)
-                        self._update_colorbar(cax, kw["cmap"], s.get_label(self._use_latex), param=magn)
+                        self._update_colorbar(cax, kw["cmap"], s.get_label(self._use_latex), param=mag)
                     xlims.append((np.amin(xx), np.amax(xx)))
                     ylims.append((np.amin(yy), np.amax(yy)))
                     zlims.append((np.nanmin(zz), np.nanmax(zz)))
 
                 elif s.is_vector:
                     xx, yy, uu, vv = self.series[i].get_data()
-                    magn = np.sqrt(uu ** 2 + vv ** 2)
+                    mag = np.sqrt(uu ** 2 + vv ** 2)
+                    uu0, vv0 = [t.copy() for t in [uu, vv]]
+                    if s.normalize:
+                        uu, vv = [t / mag for t in [uu, vv]]
                     if s.is_streamlines:
                         raise NotImplementedError
 
@@ -936,10 +1099,13 @@ class MatplotlibBackend(Plot):
                         self._handles[i][0] = self.ax.streamplot(xx, yy, uu, vv, **kw)
                     else:
                         kw, is_cb_added, cax = self._handles[i][1:]
+                        color_val = mag
+                        if s.color_func is not None:
+                            color_val = s.color_func(xx, yy, uu0, vv0)
 
                         if is_cb_added:
-                            self._handles[i][0].set_UVC(uu, vv, magn)
-                            self._update_colorbar(cax, kw["cmap"], s.get_label(self._use_latex), magn)
+                            self._handles[i][0].set_UVC(uu, vv, color_val)
+                            self._update_colorbar(cax, kw["cmap"], s.get_label(self._use_latex), color_val)
                         else:
                             self._handles[i][0].set_UVC(uu, vv)
                     xlims.append((np.amin(xx), np.amax(xx)))
@@ -948,8 +1114,7 @@ class MatplotlibBackend(Plot):
                 elif s.is_complex:
                     if not s.is_3Dsurface:
                         x, y, _, _, img, colors = s.get_data()
-                        self._handles[i][0].remove()
-                        self._handles[i][0] = self.ax.imshow(img, **self._handles[i][1])
+                        self._handles[i][0].set_data(img)
                     else:
                         x, y, mag, arg, facecolors, colorscale = s.get_data()
                         self._handles[i][0].remove()
@@ -990,12 +1155,19 @@ class MatplotlibBackend(Plot):
         self._create_figure()
         self._process_series(self.series)
 
-    def show(self):
-        """Display the current plot."""
+    def show(self, **kwargs):
+        """Display the current plot.
+
+        Parameters
+        ==========
+
+        **kwargs : dict
+            Keyword arguments to be passed to plt.show().
+        """
         self.process_series()
         if _show:
             self._fig.tight_layout()
-            self.plt.show()
+            self.plt.show(**kwargs)
         else:
             self.close()
 
