@@ -1,5 +1,7 @@
 from spb.defaults import cfg, TWO_D_B, THREE_D_B
-from spb.functions import _set_labels
+from spb.functions import (
+    _set_labels, _create_interactive_plot, _plot3d_wireframe_helper
+)
 from spb.series import (
     LineOver1DRangeSeries, ComplexSurfaceBaseSeries,
     ComplexInteractiveBaseSeries, ComplexPointSeries,
@@ -21,46 +23,26 @@ import warnings
 # * `absarg` refers to the absolute value and argument, which will be used to
 #   create "domain coloring" plots.
 
-def _build_series(*args, interactive=False, allow_lambda=False, **kwargs):
-    """
-    Parameters
-    ==========
-    interactive : boolean
-        If True, creates interactive series.
-    allow_lambda : boolean
-        If True, lambda functions are allowed to be used as expression. Not
-        all complex-relatex plotting function can support such feature, as
-        in many cases the following algorithm is going to apply symbolic
-        manipulation steps.
+def _build_complex_point_series(*args, interactive=False, allow_lambda=False, pc=False, **kwargs):
+    """The following types of arguments are supported by plot_complex_list:
+
+    * plot_complex_list(n1, n2, ...) where `n-ith` is a complex number
+    * plot_complex_list((n1, label1, rend_kw1), (n2, label2, rend_kw2), ...)
+      where `n-ith` is a complex number
+    * plot_complex_list(l1, l2, ...) where `l-ith` is a list of complex numbers
+    * plot_complex_list((l1, label1, rend_kw1), (l2, label2, rend_kw2), ...)
+      where `l-ith` is a list of complex numbers
+
+    This function implements the above logic.
+
+    NOTE: this logic needs to be separated from the logic behind plot_complex,
+    plot_real_imag, otherwise there will be ambiguities.
     """
+    series = []
     global_labels = kwargs.pop("label", [])
     global_rendering_kw = kwargs.pop("rendering_kw", None)
 
-    series = []
-    # apply the user-specified function to the expression
-    #   keys: the user specified keyword arguments
-    #   values: [function, label]
-    # NOTE: the label is going to wrap the string representation of the
-    # expression. This design choice precludes the ability of setting latex
-    # labels, but this is not a problem as the user has the ability to set
-    # a custom alias for the function to be plotted. The main motivation for
-    # this choice is that whenever re() or im() is applied to an expression, it
-    # might gets evaluated, resulting in a different expression (something
-    # that the user might not recognize). This design prevents that.
-    mapping = {
-        "real": [lambda t: re(t), "Re(%s)"],
-        "imag": [lambda t: im(t), "Im(%s)"],
-        "abs": [lambda t: sqrt(re(t)**2 + im(t)**2), "Abs(%s)"],
-        # NOTE: absarg is used to plot the absolute value colored by the
-        # argument. The colorbar indicates the argument, hence the following
-        # label is "Arg"
-        "absarg": [lambda t: t, "Arg(%s)"],
-        "arg": [lambda t: arg(t), "Arg(%s)"],
-    }
-    # option to be used with lambdify with complex functions
-    kwargs.setdefault("modules", cfg["complex"]["modules"])
-
-    if all([hasattr(a, "is_complex") and a.is_complex for a in args]):
+    if all([isinstance(a, Expr) for a in args]):
         # args is a list of complex numbers
         cls = ComplexPointSeries if not interactive else ComplexPointInteractiveSeries
         for a in args:
@@ -92,132 +74,177 @@ def _build_series(*args, interactive=False, allow_lambda=False, **kwargs):
         cls = ComplexPointSeries if not interactive else ComplexPointInteractiveSeries
         for a in args:
             series.append(cls(a, "", **kwargs))
-    else:
-        new_args = []
-
-        def add_series(argument):
-            nexpr, npar = 1, 1
-            if len([b for b in argument if _is_range(b)]) > 1:
-                # function of two variables
-                npar = 2
-            new_args.append(_check_arguments([argument], nexpr, npar)[0])
-
-        if all(isinstance(a, (list, tuple, Tuple)) for a in args):
-            # deals with the case:
-            # plot_complex((expr1, "name1"), (expr2, "name2"), range)
-            # Modify the tuples (expr, "name") to (expr, range, "name")
-            npar = len([b for b in args if _is_range(b)])
-            tmp = []
-            for i in range(len(args) - npar):
-                a = args[i]
-                tmp.append(a)
-                if len(a) == 2 and isinstance(a[-1], str):
-                    tmp[i] = (a[0], *args[len(args) - npar:], a[-1])
-
-            # plotting multiple expressions
-            for a in tmp:
-                add_series(a)
-        else:
-            if len([t for t in args if isinstance(t, Expr)]) > 1:
-                # multiple expressions with the same range
-                args = list(args)
-                r = None
-                if _is_range(args[-1]):
-                    r = args.pop()
-                for a in args:
-                    a = [a, ] if r is None else [a, r]
-                    add_series(a)
-            else:
-                # plotting a single expression
-                add_series(args)
-
-        params = kwargs.get("params", dict())
-        for a in new_args:
-            expr, ranges, label, rend_kw = a[0], a[1:-2], a[-2], a[-1]
-            if label is None:
-                label = str(expr)
-
+    elif (
+        (len(args) > 0)
+        and all([isinstance(a, (list, tuple, Tuple)) for a in args])
+        and all([len(a) > 0 for a in args])
+    ):
+        # args is a list of tuples of the form (number, label, rendering_kw)
+        # where list contains complex points
+        cls = ComplexPointSeries if not interactive else ComplexPointInteractiveSeries
+        for a in args:
+            expr, ranges, label, rkw = _unpack_args(*a)
+            # Complex points do not require ranges. However, if 3 complex
+            # points are given inside a list, _unpack_args will see them as a
+            # range.
+            expr = expr or ranges
             kw = kwargs.copy()
-            kw["rendering_kw"] = rend_kw
-            if (not allow_lambda) and callable(expr):
-                raise TypeError("expr must be a symbolic expression.")
+            kw["rendering_kw"] = rkw
+            series.append(cls([expr[0]], label, **kw))
 
-            # From now on we are dealing with a function of one variable.
-            # ranges need to contain complex numbers
-            ranges = list(ranges)
-            for i, r in enumerate(ranges):
-                ranges[i] = (r[0], complex(r[1]), complex(r[2]))
-
-            # there are expressions that are complex, but they do not represent
-            # complex points, for example `exp(I * phi)`. If it is a complex
-            # point, it won't have any free symbols.
-            fs = expr.free_symbols if isinstance(expr, Expr) else set()
-            fs = fs.difference(set(params.keys()))
-            if isinstance(expr, Expr) and expr.is_complex and (len(fs) == 0):
-                # complex number with its own label
-                cls = ComplexPointSeries if not interactive else ComplexPointInteractiveSeries
-                series.append(cls([expr], label, **kw))
-
-            else:
-                # NOTE: as a design choice, a complex function will create one
-                # or more data series, depending on the keyword arguments
-                # (one for the real part, one for the imaginary part, etc.).
-                # This is undoubtely inefficient as we must evaluate the same
-                # expression multiple times. On the other hand, it allows to
-                # maintain a one-to-one correspondance between Plot.series
-                # and backend.data, making it easier to work with iplot
-                # (backend._update_interactive).
-
-                absarg = kw.pop("absarg", True)
-                real = kw.pop("real", False)
-                imag = kw.pop("imag", False)
-                _abs = kw.pop("abs", False)
-                _arg = kw.pop("arg", False)
-
-
-
-                if ranges[0][1].imag == ranges[0][2].imag:
-                    # dealing with lines
-                    def add_series(flag, key):
-                        if flag:
-                            kw2 = kw.copy()
-                            kw2[key] = True
-                            f, lbl_wrapper = mapping[key]
-                            if not interactive:
-                                series.append(LineOver1DRangeSeries(f(expr), *ranges, lbl_wrapper % label, **kw2))
-                            else:
-                                series.append(InteractiveSeries([f(expr)], ranges, lbl_wrapper % label, **kw2))
-
-                else:
-                    # 2D domain coloring or 3D plots
-                    cls = ComplexSurfaceBaseSeries if not interactive else ComplexInteractiveBaseSeries
-                    kw.setdefault("coloring", cfg["complex"]["coloring"])
-                    def add_series(flag, key):
-                        if flag:
-                            kw2 = kw.copy()
-                            kw2[key] = True
-                            f, lbl_wrapper = mapping[key]
-                            if key == "absarg":
-                                lbl_wrapper = "%s"
-                            series.append(cls(f(expr), *ranges, lbl_wrapper % label, **kw2))
-
-                add_series(absarg, "absarg")
-                add_series(real, "real")
-                add_series(imag, "imag")
-                add_series(_abs, "abs")
-                add_series(_arg, "arg")
+    else:
+        expr, ranges, label, rkw = _unpack_args(*args)
+        if isinstance(expr, (list, tuple, Tuple)):
+            expr = expr[0]
+        cls = ComplexPointSeries if not interactive else ComplexPointInteractiveSeries
+        kw = kwargs.copy()
+        kw["rendering_kw"] = rkw
+        series.append(cls(expr, label, **kw))
 
     _set_labels(series, global_labels, global_rendering_kw)
     return series
 
 
-def _plot_complex(*args, allow_lambda=False, **kwargs):
+def _build_series(*args, interactive=False, allow_lambda=False, **kwargs):
+    series = []
+    new_args = []
+    global_labels = kwargs.pop("label", [])
+    global_rendering_kw = kwargs.pop("rendering_kw", None)
+
+    # apply the proper label.
+    # NOTE: the label is going to wrap the string representation of the
+    # expression. This design choice precludes the ability of setting latex
+    # labels, but this is not a problem as the user has the ability to set
+    # a custom alias for the function to be plotted.
+    mapping = {
+        "real": "Re(%s)",
+        "imag": "Im(%s)",
+        "abs": "Abs(%s)",
+        # NOTE: absarg is used to plot the absolute value colored by the
+        # argument. The colorbar indicates the argument, hence the following
+        # label is "Arg"
+        "absarg": "Arg(%s)",
+        "arg": "Arg(%s)",
+    }
+    # option to be used with lambdify with complex functions
+    kwargs.setdefault("modules", cfg["complex"]["modules"])
+
+    def add_series(argument):
+        nexpr, npar = 1, 1
+        if len([b for b in argument if _is_range(b)]) > 1:
+            # function of two variables
+            npar = 2
+        new_args.append(_check_arguments([argument], nexpr, npar)[0])
+
+    if all(isinstance(a, (list, tuple, Tuple)) for a in args):
+        # deals with the case:
+        # plot_complex((expr1, "name1"), (expr2, "name2"), range)
+        # Modify the tuples (expr, "name") to (expr, range, "name")
+        npar = len([b for b in args if _is_range(b)])
+        tmp = []
+        for i in range(len(args) - npar):
+            a = args[i]
+            tmp.append(a)
+            if len(a) == 2 and isinstance(a[-1], str):
+                tmp[i] = (a[0], *args[len(args) - npar:], a[-1])
+
+        # plotting multiple expressions
+        for a in tmp:
+            add_series(a)
+    else:
+        exprs, r, label, rkw = _unpack_args(*args)
+        for e in exprs:
+            add_series([e, *r, label, rkw])
+
+    params = kwargs.get("params", dict())
+    for a in new_args:
+        expr, ranges, label, rend_kw = a[0], a[1:-2], a[-2], a[-1]
+        if label is None:
+            label = str(expr)
+
+        kw = kwargs.copy()
+        kw["rendering_kw"] = rend_kw
+        if (not allow_lambda) and callable(expr):
+            raise TypeError("expr must be a symbolic expression.")
+
+        # From now on we are dealing with a function of one variable.
+        # ranges need to contain complex numbers
+        ranges = list(ranges)
+        for i, r in enumerate(ranges):
+            ranges[i] = (r[0], complex(r[1]), complex(r[2]))
+
+        # NOTE:
+        # 1. as a design choice, a complex function will create one
+        #    or more data series, depending on the keyword arguments
+        #    (one for the real part, one for the imaginary part, etc.).
+        #    This is undoubtely inefficient as we must evaluate the same
+        #    expression multiple times. On the other hand, it allows to
+        #    maintain a one-to-one correspondance between Plot.series
+        #    and backend.data, making it easier to work with iplot
+        #    (backend._update_interactive).
+        # 2. The expression used on each data series is the same one
+        #    provided by the user. Each data series will receive the `return`
+        #    keyword argument, which specify what data must be returned.
+        #    So, if return="real", the series will return the real part
+        #    of the function, and so on.
+        #    Why not applying SymPy's re(), im(), arg(), ..., to the original
+        #    expression and get rid of `return`? Because `re()` and `im()`
+        #    evaluate the expression, usually creating new expressions
+        #    containing many more terms, hence much slower evaluation. Instead,
+        #    the series are going to evaluate the complex function and then
+        #    extract the required data.
+
+        absarg = kw.pop("absarg", True)
+        real = kw.pop("real", False)
+        imag = kw.pop("imag", False)
+        _abs = kw.pop("abs", False)
+        _arg = kw.pop("arg", False)
+
+        if ranges[0][1].imag == ranges[0][2].imag:
+            # dealing with lines
+            def add_series(flag, key):
+                if flag:
+                    kw2 = kw.copy()
+                    kw2[key] = True
+                    kw2["return"] = key
+                    lbl_wrapper = mapping[key]
+                    if not interactive:
+                        series.append(LineOver1DRangeSeries(expr, *ranges, lbl_wrapper % label, **kw2))
+                    else:
+                        series.append(InteractiveSeries([expr], ranges, lbl_wrapper % label, **kw2))
+
+        else:
+            # 2D domain coloring or 3D plots
+            cls = ComplexSurfaceBaseSeries if not interactive else ComplexInteractiveBaseSeries
+            kw.setdefault("coloring", cfg["complex"]["coloring"])
+            def add_series(flag, key):
+                if flag:
+                    kw2 = kw.copy()
+                    kw2[key] = True
+                    kw2["return"] = key
+                    lbl_wrapper = mapping[key]
+                    if key == "absarg":
+                        lbl_wrapper = "%s"
+                    series.append(cls(expr, *ranges, lbl_wrapper % label, **kw2))
+
+        add_series(absarg, "absarg")
+        add_series(real, "real")
+        add_series(imag, "imag")
+        add_series(_abs, "abs")
+        add_series(_arg, "arg")
+
+    _set_labels(series, global_labels, global_rendering_kw)
+    series += _plot3d_wireframe_helper(series, **kwargs)
+    return series
+
+
+def _plot_complex(*args, allow_lambda=False, pcl=False, **kwargs):
     """Create the series and setup the backend."""
     args = _plot_sympify(args)
     kwargs = _set_discretization_points(kwargs, ComplexSurfaceBaseSeries)
     kwargs["is_complex"] = True
 
-    if kwargs.get("params", None):
+    if (not pcl) and kwargs.get("params", None):
         # NOTE: the iplot module is really slow to load, so let's load it
         # only when it is necessary
         from spb.interactive import iplot
@@ -225,17 +252,33 @@ def _plot_complex(*args, allow_lambda=False, **kwargs):
         args = _check_arguments(args, 1, 1, **kwargs)
         return iplot(*args, **kwargs)
 
-    series = _build_series(*args, allow_lambda=allow_lambda, **kwargs)
+    if not pcl:
+        series = _build_series(*args, allow_lambda=allow_lambda, **kwargs)
+    else:
+        params = kwargs.get("params", None)
+        if params:
+            kwargs["interactive"] = True
+            mod_params = None
+            # NOTE: it was easier to not implement a List2DInteractiveSeries.
+            # Hence, List2DSeries can be interactive (if params is provided)
+            # or not. If it is interactive, we must provide ``params`` with the
+            # correct form, meaning mapping symbols to values.
+            mod_params = {k: v[0] for k, v in params.items()}
+            kwargs["params"] = mod_params
+        series = _build_complex_point_series(*args, allow_lambda=allow_lambda, pcl=True, **kwargs)
     if len(series) == 0:
         warnings.warn("No series found. Check your keyword arguments.")
 
+    _set_axis_labels(series, kwargs)
+
+    if pcl:
+        return series
+
     if any(s.is_3Dsurface for s in series):
         Backend = kwargs.pop("backend", THREE_D_B)
     else:
         Backend = kwargs.pop("backend", TWO_D_B)
 
-    _set_axis_labels(series, kwargs)
-
     return _instantiate_backend(Backend, *series, **kwargs)
 
 
@@ -280,7 +323,7 @@ def plot_real_imag(*args, **kwargs):
     """Plot the real part, the imaginary parts, the absolute value and the
     argument of a complex function. By default, only the real and imaginary
     parts will be plotted. Use keyword argument to be more specific.
-    By default, the aspect ratio of the plot is set to `aspect="equal"`.
+    By default, the aspect ratio of the plot is set to ``aspect="equal"``.
 
     Depending on the provided expression, this function will produce different
     types of plots:
@@ -319,7 +362,8 @@ def plot_real_imag(*args, **kwargs):
               ranges by using standard Python complex numbers, for example
               `(z, -5+2j, 5+2j)`.
             * `(z, -5 - 3*I, 5 + 3*I)`: surface or contour plot of the
-              complex function over the specified domain.
+              complex function over the specified domain using a rectangular
+              discretization.
 
         label : str, optional
             The name of the complex function to be eventually shown on the
@@ -545,25 +589,32 @@ def plot_real_imag(*args, **kwargs):
     Interactive-widget plot. Refer to ``iplot`` documentation to learn more
     about the ``params`` dictionary.
 
-    .. code-block:: python
+    .. panel-screenshot::
+       :small-size: 800, 600
 
        from sympy import *
        from spb import *
        x, u = symbols("x, u")
        plot_real_imag(sqrt(x) * exp(-u * x**2), (x, -3, 3),
-           params={u: (1, 0, 2)}, ylim=(-0.25, 2))
+           params={u: (1, 0, 2)}, ylim=(-0.25, 2), use_latex=False)
 
-    3D plot of the real and imaginary part of a function over a complex range:
+    3D plot of the real and imaginary part of the principal branch of a
+    function over a complex range. Note the jump in the imaginary part: that's
+    a branch cut. The rectangular discretization is unable to properly capture
+    it, hence the near vertical wall. Refer to ``plot3d_parametric_surface``
+    for an example about plotting Riemann surfaces and properly capture
+    the branch cuts.
 
     .. plot::
        :context: close-figs
        :format: doctest
        :include-source: True
 
-       >>> plot_real_imag(sqrt(x), (x, -3-3j, 3+3j), n=100, threed=True)
+       >>> plot_real_imag(sqrt(x), (x, -3-3j, 3+3j), n=100, threed=True,
+       ...      use_cm=True)
        Plot object containing:
-       [0]: cartesian surface: (re(x)**2 + im(x)**2)**(1/4)*cos(atan2(im(x), re(x))/2) for re(x) over (-3.0, 3.0) and im(x) over (-3.0, 3.0)
-       [1]: cartesian surface: (re(x)**2 + im(x)**2)**(1/4)*sin(atan2(im(x), re(x))/2) for re(x) over (-3.0, 3.0) and im(x) over (-3.0, 3.0)
+       [0]: complex cartesian surface: (re(x)**2 + im(x)**2)**(1/4)*cos(atan2(im(x), re(x))/2) for re(x) over (-3.0, 3.0) and im(x) over (-3.0, 3.0)
+       [1]: complex cartesian surface: (re(x)**2 + im(x)**2)**(1/4)*sin(atan2(im(x), re(x))/2) for re(x) over (-3.0, 3.0) and im(x) over (-3.0, 3.0)
 
     3D plot of the absolute value of a function over a complex range:
 
@@ -580,14 +631,15 @@ def plot_real_imag(*args, **kwargs):
     3D interactive-widget plot. Refer to ``iplot`` documentation to learn more
     about the ``params`` dictionary.
 
-    .. code-block:: python
+    .. panel-screenshot::
+       :small-size: 800, 600
 
        from sympy import *
        from spb import *
        x, u = symbols("x, u")
        plot_real_imag(
            sqrt(x) * exp(u * x), (x, -3-3j, 3+3j),
-           params={u: (0.5, 0, 1)}, n=25, threed=True)
+           params={u: (0.5, 0, 1)}, n=25, threed=True, use_latex=False)
 
     References
     ==========
@@ -610,7 +662,7 @@ def plot_real_imag(*args, **kwargs):
 
 def plot_complex(*args, **kwargs):
     """Plot the absolute value of a complex function colored by its argument.
-    By default, the aspect ratio of the plot is set to `aspect="equal"`.
+    By default, the aspect ratio of the plot is set to ``aspect="equal"``.
 
     Depending on the provided range, this function will produce different
     types of plots:
@@ -618,10 +670,12 @@ def plot_complex(*args, **kwargs):
     1. Line plot over the reals.
     2. Image plot over the complex plane if `threed=False`. This is also
        known as Domain Coloring. Use the `coloring` keyword argument to
-       select a different color scheme.
+       select a different color scheme. At the moment, only HSV coloring is
+       supported.
     3. If `threed=True`, plot a 3D surface of the absolute value over the
        complex plane, colored by its argument. Use the `coloring` keyword
-       argument to select a different color scheme.
+       argument to select a different color scheme. At the moment, only HSV
+       coloring is supported.
 
     Typical usage examples are in the followings:
 
@@ -848,32 +902,35 @@ def plot_complex(*args, **kwargs):
 
        >>> plot_complex(cos(x) + sin(I * x), "f", (x, -2, 2))
        Plot object containing:
-       [0]: absolute-argument line: cos(x) + I*sinh(x) for x over ((-2+0j), (2+0j))
+       [0]: cartesian abs-arg line: cos(x) + I*sinh(x) for x over ((-2+0j), (2+0j))
 
     Interactive-widget plot. Refer to ``iplot`` documentation to learn more
     about the ``params`` dictionary.
 
-    .. code-block:: python
+    .. panel-screenshot::
+       :small-size: 800, 600
 
        from sympy import *
        from spb import *
        x, u = symbols("x, u")
        plot_complex(
            exp(I * x) * I * sin(u * x), "f", (x, -5, 5),
-           params={u: (1, 0, 2)}, ylim=(-0.2, 1.2))
+           params={u: (1, 0, 2)}, ylim=(-0.2, 1.2), use_latex=False)
 
-    Domain coloring plot. Note that it might be necessary to increase the
-    number of discretization points in order to get a smoother plot:
+    Domain coloring plot. To improve the smoothness of the results, increase
+    the number of discretization points and/or apply an interpolation (if the
+    backend supports it):
 
     .. plot::
        :context: close-figs
        :format: doctest
        :include-source: True
 
-       >>> plot_complex(gamma(z), (z, -3 - 3*I, 3 + 3*I),
+       >>> plot_complex(gamma(z), (z, -3-3j, 3+3j),
+       ...     {"interpolation": "spline36"}, # passed to matplotlib's imshow
        ...     coloring="b", n=500, grid=False)
        Plot object containing:
-       [0]: domain coloring: gamma(z) for re(z) over (-3.0, 3.0) and im(z) over (-3.0, 3.0)
+       [0]: complex domain coloring: gamma(z) for re(z) over (-3.0, 3.0) and im(z) over (-3.0, 3.0)
 
     Plotting a numerical function instead of a symbolic expression:
 
@@ -884,33 +941,35 @@ def plot_complex(*args, **kwargs):
 
        >>> import numpy as np
        >>> plot_complex(lambda z: z, ("z", -5-5j, 5+5j),
-       ...     coloring="b", n=1000, grid=False)
+       ...     {"interpolation": "spline36"}, # passed to matplotlib's imshow
+       ...     coloring="b", n=600, grid=False)
 
     Interactive-widget domain coloring plot. Refer to ``iplot`` documentation
     to learn more about the ``params`` dictionary. Note that a too large
     value of ``n`` will impact performance.
 
-    .. code-block:: python
+    .. panel-screenshot::
+       :small-size: 800, 600
 
        from sympy import *
        from spb import *
-       x, u = symbols("x, u")
+       z, u = symbols("z, u")
        plot_complex(
-           gamma(u * z), (z, -3 - 3*I, 3 + 3*I),
-           coloring="b", n=250, grid=False, params={u: (1, 0, 2)})
+           sin(u * z), (z, -pi - pi*I, pi + pi*I),
+           {"interpolation": "spline36"}, use_latex=False,
+           coloring="b", n=250, grid=False, params={u: (0.5, 0, 2)})
 
     3D plot of the absolute value of a complex function colored by its
-    argument:
+    argument, using Plotly:
 
-    .. plot::
-       :context: close-figs
-       :format: doctest
-       :include-source: True
+    .. plotly::
+       :context: reset
 
-       >>> plot_complex(gamma(z), (z, -3 - 3*I, 3 + 3*I), threed=True,
-       ...     zlim=(-1, 6))
-       Plot object containing:
-       [0]: cartesian surface: gamma(z) for re(z) over (-3.0, 3.0) and im(z) over (-3.0, 3.0)
+       from sympy import symbols, gamma, I
+       from spb import plot_complex, PB
+       z = symbols('z')
+       plot_complex(gamma(z), (z, -3 - 3*I, 3 + 3*I), threed=True,
+           backend=PB, zlim=(-1, 6), use_cm=True)
 
 
     References
@@ -938,7 +997,7 @@ def plot_complex(*args, **kwargs):
 
 def plot_complex_list(*args, **kwargs):
     """Plot lists of complex points. By default, the aspect ratio of the plot
-    is set to `aspect="equal"`.
+    is set to ``aspect="equal"``.
 
     Typical usage examples are in the followings:
 
@@ -1059,9 +1118,9 @@ def plot_complex_list(*args, **kwargs):
 
        >>> plot_complex_list(3 + 2 * I, 4 * I, 2)
        Plot object containing:
-       [0]: complex point (3 + 2*I,)
-       [1]: complex point (4*I,)
-       [2]: complex point (2,)
+       [0]: complex points: (3 + 2*I,)
+       [1]: complex points: (4*I,)
+       [2]: complex points: (2,)
 
     Plot two lists of complex points and assign to them custom labels:
 
@@ -1077,13 +1136,14 @@ def plot_complex_list(*args, **kwargs):
        >>> l2 = [expr2.subs(z, t / n) for t in range(n)]
        >>> plot_complex_list((l1, "f1"), (l2, "f2"))
        Plot object containing:
-       [0]: complex points (0.0, 0.0666666666666667*exp(0.133333333333333*I*pi), 0.133333333333333*exp(0.266666666666667*I*pi), 0.2*exp(0.4*I*pi), 0.266666666666667*exp(0.533333333333333*I*pi), 0.333333333333333*exp(0.666666666666667*I*pi), 0.4*exp(0.8*I*pi), 0.466666666666667*exp(0.933333333333333*I*pi), 0.533333333333333*exp(1.06666666666667*I*pi), 0.6*exp(1.2*I*pi), 0.666666666666667*exp(1.33333333333333*I*pi), 0.733333333333333*exp(1.46666666666667*I*pi), 0.8*exp(1.6*I*pi), 0.866666666666667*exp(1.73333333333333*I*pi), 0.933333333333333*exp(1.86666666666667*I*pi))
-       [1]: complex points (0, 0.133333333333333*exp(0.133333333333333*I*pi), 0.266666666666667*exp(0.266666666666667*I*pi), 0.4*exp(0.4*I*pi), 0.533333333333333*exp(0.533333333333333*I*pi), 0.666666666666667*exp(0.666666666666667*I*pi), 0.8*exp(0.8*I*pi), 0.933333333333333*exp(0.933333333333333*I*pi), 1.06666666666667*exp(1.06666666666667*I*pi), 1.2*exp(1.2*I*pi), 1.33333333333333*exp(1.33333333333333*I*pi), 1.46666666666667*exp(1.46666666666667*I*pi), 1.6*exp(1.6*I*pi), 1.73333333333333*exp(1.73333333333333*I*pi), 1.86666666666667*exp(1.86666666666667*I*pi))
+       [0]: complex points: (0.0, 0.0666666666666667*exp(0.133333333333333*I*pi), 0.133333333333333*exp(0.266666666666667*I*pi), 0.2*exp(0.4*I*pi), 0.266666666666667*exp(0.533333333333333*I*pi), 0.333333333333333*exp(0.666666666666667*I*pi), 0.4*exp(0.8*I*pi), 0.466666666666667*exp(0.933333333333333*I*pi), 0.533333333333333*exp(1.06666666666667*I*pi), 0.6*exp(1.2*I*pi), 0.666666666666667*exp(1.33333333333333*I*pi), 0.733333333333333*exp(1.46666666666667*I*pi), 0.8*exp(1.6*I*pi), 0.866666666666667*exp(1.73333333333333*I*pi), 0.933333333333333*exp(1.86666666666667*I*pi))
+       [1]: complex points: (0, 0.133333333333333*exp(0.133333333333333*I*pi), 0.266666666666667*exp(0.266666666666667*I*pi), 0.4*exp(0.4*I*pi), 0.533333333333333*exp(0.533333333333333*I*pi), 0.666666666666667*exp(0.666666666666667*I*pi), 0.8*exp(0.8*I*pi), 0.933333333333333*exp(0.933333333333333*I*pi), 1.06666666666667*exp(1.06666666666667*I*pi), 1.2*exp(1.2*I*pi), 1.33333333333333*exp(1.33333333333333*I*pi), 1.46666666666667*exp(1.46666666666667*I*pi), 1.6*exp(1.6*I*pi), 1.73333333333333*exp(1.73333333333333*I*pi), 1.86666666666667*exp(1.86666666666667*I*pi))
 
     Interactive-widget plot. Refer to ``iplot`` documentation to learn more
     about the ``params`` dictionary.
 
-    .. code-block:: python
+    .. panel-screenshot::
+       :small-size: 800, 600
 
        from sympy import *
        from spb import *
@@ -1095,7 +1155,7 @@ def plot_complex_list(*args, **kwargs):
        l2 = [expr2.subs(z, t / n) for t in range(n)]
        plot_complex_list(
            (l1, "f1"), (l2, "f2"),
-           params={u: (0.5, 0, 2)},
+           params={u: (0.5, 0, 2)}, use_latex=False,
            xlim=(-1.5, 2), ylim=(-2, 1))
 
 
@@ -1111,13 +1171,19 @@ def plot_complex_list(*args, **kwargs):
     kwargs["real"] = False
     kwargs["imag"] = False
     kwargs["threed"] = False
-    return _plot_complex(*args, allow_lambda=False, **kwargs)
+    series = _plot_complex(*args, allow_lambda=False, pcl=True, **kwargs)
+    if "params" in kwargs.keys():
+        kwargs["series"] = series
+        return _create_interactive_plot(**kwargs)
+
+    Backend = kwargs.pop("backend", TWO_D_B)
+    return _instantiate_backend(Backend, *series, **kwargs)
 
 
 def plot_complex_vector(*args, **kwargs):
     """Plot the vector field `[re(f), im(f)]` for a complex function `f`
     over the specified complex domain. By default, the aspect ratio of the
-    plot is set to `aspect="equal"`.
+    plot is set to ``aspect="equal"``.
 
     Typical usage examples are in the followings:
 
@@ -1254,26 +1320,26 @@ def plot_complex_vector(*args, **kwargs):
        :format: doctest
        :include-source: True
 
-       >>> from sympy import I, symbols, exp, sqrt, cos, sin, pi, gamma
-       >>> from spb import plot_complex_vector
+       >>> from sympy import I, symbols, gamma, latex, log
+       >>> from spb import plot_complex_vector, plot_complex
        >>> z = symbols('z')
 
-    Quivers plot with a contour plot in background representing the
-    vector's magnitude (a scalar field).
+    Quivers plot with normalize lengths and a contour plot in background
+    representing the vector's magnitude (a scalar field).
 
     .. plot::
        :context: close-figs
        :format: doctest
        :include-source: True
 
-       >>> expr = z**2
+       >>> expr = z**2 + 2
        >>> plot_complex_vector(expr, (z, -5 - 5j, 5 + 5j),
-       ...     quiver_kw=dict(color="orange"), grid=False)
+       ...     quiver_kw=dict(color="orange"), normalize=True, grid=False)
        Plot object containing:
-       [0]: contour: sqrt(((re(_x) - im(_y))**2 - (re(_y) + im(_x))**2)**2 + 4*(re(_x) - im(_y))**2*(re(_y) + im(_x))**2) for _x over (-5.0, 5.0) and _y over (-5.0, 5.0)
-       [1]: 2D vector series: [(re(_x) - im(_y))**2 - (re(_y) + im(_x))**2, 2*(re(_x) - im(_y))*(re(_y) + im(_x))] over (_x, -5.0, 5.0), (_y, -5.0, 5.0)
+       [0]: contour: sqrt(4*(re(_x) - im(_y))**2*(re(_y) + im(_x))**2 + ((re(_x) - im(_y))**2 - (re(_y) + im(_x))**2 + 2)**2) for _x over (-5.0, 5.0) and _y over (-5.0, 5.0)
+       [1]: 2D vector series: [(re(_x) - im(_y))**2 - (re(_y) + im(_x))**2 + 2, 2*(re(_x) - im(_y))*(re(_y) + im(_x))] over (_x, -5.0, 5.0), (_y, -5.0, 5.0)
 
-    Only quiver plot.
+    Only quiver plot with normalized lengths and solid color.
 
     .. plot::
        :context: close-figs
@@ -1281,9 +1347,9 @@ def plot_complex_vector(*args, **kwargs):
        :include-source: True
 
        >>> plot_complex_vector(expr, (z, -5 - 5j, 5 + 5j),
-       ...     "Magnitude of %s" % str(expr), scalar=False)
+       ...     scalar=False, use_cm=False, normalize=True)
        Plot object containing:
-       [0]: 2D vector series: [(re(_x) - im(_y))**2 - (re(_y) + im(_x))**2, 2*(re(_x) - im(_y))*(re(_y) + im(_x))] over (_x, -5.0, 5.0), (_y, -5.0, 5.0)
+       [0]: 2D vector series: [(re(_x) - im(_y))**2 - (re(_y) + im(_x))**2 + 2, 2*(re(_x) - im(_y))*(re(_y) + im(_x))] over (_x, -5.0, 5.0), (_y, -5.0, 5.0)
 
     Only streamlines plot.
 
@@ -1293,34 +1359,44 @@ def plot_complex_vector(*args, **kwargs):
        :include-source: True
 
        >>> plot_complex_vector(expr, (z, -5 - 5j, 5 + 5j),
-       ...     "Magnitude of %s" % str(expr), scalar=False, streamlines=True)
+       ...     "Magnitude of $%s$" % latex(expr),
+       ...     scalar=False, streamlines=True)
        Plot object containing:
-       [0]: 2D vector series: [(re(_x) - im(_y))**2 - (re(_y) + im(_x))**2, 2*(re(_x) - im(_y))*(re(_y) + im(_x))] over (_x, -5.0, 5.0), (_y, -5.0, 5.0)
+       [0]: 2D vector series: [(re(_x) - im(_y))**2 - (re(_y) + im(_x))**2 + 2, 2*(re(_x) - im(_y))*(re(_y) + im(_x))] over (_x, -5.0, 5.0), (_y, -5.0, 5.0)
 
-    Quivers plot for multiple complex expressions:
+    Overlay the quiver plot to a domain coloring plot. By setting ``n=26``
+    (even number) in the complex vector plot, the quivers won't to cross
+    the branch cut.
 
     .. plot::
        :context: close-figs
        :format: doctest
        :include-source: True
 
-       >>> plot_complex_vector((z**2, (z, -5 - 5j, 5 + 0j)), (z**3, (z, -5 - 0j, 5 + 5j)))
+       >>> expr = z * log(2 * z) + 3
+       >>> p1 = plot_complex(expr, (z, -2-2j, 2+2j), grid=False, show=False)
+       >>> p2 = plot_complex_vector(expr, (z, -2-2j, 2+2j),
+       ...      n=26, grid=False, scalar=False, use_cm=False, normalize=True,
+       ...      quiver_kw={"color": "k", "pivot": "tip"}, show=False)
+       >>> (p1 + p2).show()
+       >>> (p1 + p2)
        Plot object containing:
-       [0]: 2D vector series: [(re(_x) - im(_y))**2 - (re(_y) + im(_x))**2, 2*(re(_x) - im(_y))*(re(_y) + im(_x))] over (_x, -5.0, 5.0), (_y, -5.0, 0.0)
-       [1]: 2D vector series: [(re(_x) - im(_y))**3 - 3*(re(_x) - im(_y))*(re(_y) + im(_x))**2, 3*(re(_x) - im(_y))**2*(re(_y) + im(_x)) - (re(_y) + im(_x))**3] over (_x, -5.0, 5.0), (_y, 0.0, 5.0)
+       [0]: complex domain coloring: z*log(2*z) + 3 for re(z) over (-2.0, 2.0) and im(z) over (-2.0, 2.0)
+       [1]: 2D vector series: [(re(_x) - im(_y))*log(Abs(2*_x + 2*_y*I)) - (re(_y) + im(_x))*arg(_x + _y*I) + 3, (re(_x) - im(_y))*arg(_x + _y*I) + (re(_y) + im(_x))*log(Abs(2*_x + 2*_y*I))] over (_x, -2.0, 2.0), (_y, -2.0, 2.0)
 
     Interactive-widget plot. Refer to ``iplot`` documentation to learn more
     about the ``params`` dictionary.
 
-    .. code-block:: python
+    .. panel-screenshot::
+       :small-size: 800, 600
 
        from sympy import *
        from spb import *
        z, u = symbols("z u")
        plot_complex_vector(
-           log(gamma(u * z)), (z, -5 - 5j, 5 + 5j),
-           params={u: (1, 0, 2)}, n=20,
-           quiver_kw=dict(color="orange"), grid=False)
+            log(gamma(u * z)), (z, -5 - 5j, 5 + 5j),
+            params={u: (1, 0, 2)}, n=20, grid=False, use_latex=False,
+            quiver_kw=dict(color="orange", headwidth=4))
 
     See Also
     ========
@@ -1328,13 +1404,13 @@ def plot_complex_vector(*args, **kwargs):
     plot_real_imag, plot_complex, plot_complex_list, plot_vector, iplot
 
     """
-    # for each argument, generate two series: one for the real part and
-    # another for the imaginary part
+    # for each argument, generate one series. Those series will be used to
+    # generate the proper input arguments for plot_vector
     kwargs["absarg"] = False
     kwargs["abs"] = False
     kwargs["arg"] = False
     kwargs["real"] = True
-    kwargs["imag"] = True
+    kwargs["imag"] = False
     kwargs["threed"] = False
     kwargs.setdefault("xlabel", "Re")
     kwargs.setdefault("ylabel", "Im")
@@ -1343,7 +1419,7 @@ def plot_complex_vector(*args, **kwargs):
     args = _plot_sympify(args)
     params = kwargs.get("params", None)
     series = _build_series(*args, allow_lambda=False, **kwargs)
-    multiple_expr = len(series) > 2
+    multiple_expr = len(series) > 1
 
     def get_label(i):
         _iterable = args[i] if multiple_expr else args
@@ -1355,12 +1431,11 @@ def plot_complex_vector(*args, **kwargs):
     # create new arguments to be used by plot_vector
     new_args = []
     x, y = symbols("x, y", cls=Dummy)
-    for i in range(int(len(series) / 2)):
-        s1 = series[2 * i]
-        s2 = series[2 * i + 1]
-        expr1 = s1.expr
-        expr2 = s2.expr
-        free_symbols = expr1.free_symbols
+    for i in range(len(series)):
+        s1 = series[i]
+        expr1 = re(s1.get_expr())
+        expr2 = im(s1.get_expr())
+        free_symbols = s1.get_expr().free_symbols
         if params is not None:
             free_symbols = free_symbols.difference(params.keys())
         free_symbols = list(free_symbols)
