@@ -1,5 +1,5 @@
 from spb.defaults import cfg
-from sympy import Tuple, sympify, Expr, Dummy, S
+from sympy import Tuple, sympify, Expr, Dummy, S, sin, cos
 from sympy.matrices.dense import DenseMatrix
 from sympy.physics.mechanics import Vector as MechVector
 from sympy.vector import Vector
@@ -184,7 +184,9 @@ def _check_arguments(args, nexpr, npar, **kwargs):
             rend_kw = [a for a in arg if isinstance(a, dict)]
             rend_kw = rendering_kw if len(rend_kw) == 0 else rend_kw[0]
 
-            arg = arg[:nexpr]
+            # NOTE: arg = arg[:nexpr] may raise an exception if lambda
+            # functions are used. Execute the following instead:
+            arg = [arg[i] for i in range(nexpr)]
             free_symbols = set()
             if all(not callable(a) for a in arg):
                 free_symbols = free_symbols.union(*[a.free_symbols for a in arg])
@@ -367,6 +369,8 @@ def _split_vector(expr, ranges, fill_ranges=True):
             + "Received: {}. Number of elements: {}".format(expr, len(expr))
         )
 
+    # TODO: since plot_vector requires all ranges to be specified, this
+    # code block can be eliminated. It requires adjusting some tests...
     if fill_ranges:
         ranges = list(ranges)
         fs = set()
@@ -378,13 +382,20 @@ def _split_vector(expr, ranges, fill_ranges=True):
                 if s not in fs_ranges:
                     ranges.append(Tuple(s, cfg["plot_range"]["min"], cfg["plot_range"]["max"]))
 
+    if (len(ranges) == 2) and (len(expr) == 3):
+        # There might be ambiguities when working with vectors from
+        # sympy.vector. Let f(x, y) be a scalar field. The gradient of f(x, y)
+        # is going to be a 2D vector field. However, at this point it will
+        # have 3 components, one of which is zero. Let's assume the last one
+        # is zero and skip it.
+        expr = expr[:2]
+
     if len(expr) == 2:
         xexpr, yexpr = expr
-        zexpr = S.Zero
+        return (xexpr, yexpr), ranges
     else:
         xexpr, yexpr, zexpr = expr
-    split_expr = xexpr, yexpr, zexpr
-    return split_expr, ranges
+        return (xexpr, yexpr, zexpr), ranges
 
 
 def _instantiate_backend(Backend, *series, **kwargs):
@@ -422,7 +433,7 @@ def _validate_kwargs(backend_obj, **kwargs):
 
     1. Replace **kwargs everywhere with the actual expected keywords.
        This is very time consuming and hard to maintain as the module gets
-       developed even further. Morover, Python will raise an error everytime
+       developed even further. Moreover, Python will raise an error everytime
        something get mispelled, which I think is annoying.
     2. Perform "multiple levels" of keyword validation, at a plotting function
        level (on each function), at a series level and at a backend level.
@@ -452,13 +463,15 @@ def _validate_kwargs(backend_obj, **kwargs):
     allowed_keys = allowed_keys.union([
         "is_interactive", "abs", "absarg", "arg", "real", "imag",
         "is_complex", "is_vector", "slice", "threed", "sum_bound", "n",
-        "phaseres", "is_polar", "label"
+        "phaseres", "is_polar", "label",
+        "wireframe", "wf_n1", "wf_n2", "wf_npoints", "wf_rendering_kw",
+        "dots",
     ])
     # params is a keyword argument that is also checked before instantion of
     # Series and Backend.
     allowed_keys = allowed_keys.union(["params", "layout", "ncols",
         "use_latex", "throttled", "servable", "custom_css", "pane_kw",
-        "is_iplot"])
+        "is_iplot", "series"])
     user_provided_keys = set(kwargs.keys())
     unused_keys = user_provided_keys.difference(allowed_keys)
     if len(unused_keys) > 0:
@@ -501,3 +514,32 @@ def find_closest_string(string, strings):
         return (levenshtein(s, string), s)
 
     return sorted(strings, key=_key)[0]
+
+
+def spherical_to_cartesian(r, theta, phi):
+    """Convert spherical coordinates to cartesian coordinates.
+
+    Parameters
+    ==========
+        r :
+            Radius.
+        theta :
+            Polar angle. Must be in [0, pi]. 0 is the north pole, pi/2 is the
+            equator, pi is the south pole.
+        phi :
+            Azimuthal angle. Must be in [0, 2*pi].
+
+    Returns
+    =======
+        x, y, z
+    """
+    if callable(r):
+        np = import_module('numpy')
+        x = lambda t, p: r(t, p) * np.sin(t) * np.cos(p)
+        y = lambda t, p: r(t, p) * np.sin(t) * np.sin(p)
+        z = lambda t, p: r (t, p)* np.cos(t)
+    else:
+        x = r * sin(theta) * cos(phi)
+        y = r * sin(theta) * sin(phi)
+        z = r * cos(theta)
+    return x, y, z
