@@ -121,7 +121,7 @@ def _series(expr, *ranges, label="", interactive=False, **kwargs):
     # parameters
     fs = fs.difference(params.keys())
 
-    if split_expr[2] is S.Zero:  # 2D case
+    if len(split_expr) == 2:  # 2D case
         kwargs = _set_discretization_points(kwargs.copy(), Vector2DSeries)
         if len(fs) > 2:
             raise ValueError(
@@ -152,12 +152,12 @@ def _series(expr, *ranges, label="", interactive=False, **kwargs):
             return (
                 split_expr,
                 ranges,
-                Vector2DSeries(*split_expr[:2], *ranges, label, **kwargs),
+                Vector2DSeries(*split_expr, *ranges, label, **kwargs),
             )
         return (
             split_expr,
             ranges,
-            InteractiveSeries(split_expr[:2], ranges, label, **kwargs),
+            InteractiveSeries(split_expr, ranges, label, **kwargs),
         )
     else:  # 3D case
         kwargs = _set_discretization_points(kwargs.copy(), Vector3DSeries)
@@ -301,7 +301,7 @@ def plot_vector(*args, **kwargs):
 
         ranges : 3-element tuples
             Denotes the range of the variables. For example (x, -5, 5). For 2D
-            vector plots, 2 ranges should be provided. For 3D vector plots, 3
+            vector plots, 2 ranges must be provided. For 3D vector plots, 3
             ranges are needed.
 
         label : str, optional
@@ -318,6 +318,18 @@ def plot_vector(*args, **kwargs):
         A subclass of `Plot`, which will perform the rendering.
         Default to `MatplotlibBackend`.
 
+    color_func : callable, optional
+        A numerical function to map quivers (or streamlines) colors to a
+        colormap. It must be:
+
+        * ``f(x, y, u, v)`` for a 2D vector field. Further, ``scalar=False``
+          must be set in order to hide the contour plot so that a colormap
+          is applied to quivers/streamlines.
+        * ``f(x, y, z, u, v, w)`` for a 3D vector field.
+
+        Default to None, which will map colors according to the magnitude of
+        the vector.
+
     contour_kw : dict
         A dictionary of keywords/values which is passed to the backend
         contour function to customize the appearance. Refer to the plotting
@@ -326,8 +338,16 @@ def plot_vector(*args, **kwargs):
     label : list/tuple, optional
         The label to be shown in the colorbar if ``scalar=None``.
         If not provided, the string representation of `expr` will be used.
+
         The number of labels must be equal to the number of series generated
-        by the plotting function.
+        by the plotting function. For example:
+
+        * if a scalar field and a quiver (or streamline) are shown
+          simultaneously, then two labels must be provided;
+        * if only a quiver (or streamline) is shown, then one label must be
+          provided.
+        * if two or more quivers (or streamlines) are shown, then two or more
+          labels must be provided.
 
     n1, n2, n3 : int
         Number of discretization points for the quivers or streamlines in the
@@ -342,6 +362,12 @@ def plot_vector(*args, **kwargs):
         Number of discretization points for the scalar contour plot.
         Default to 100.
 
+    normalize : bool
+        Default to False. If True, the vector field will be normalized,
+        resulting in quivers having the same length. If ``use_cm=True``, the
+        backend will color the quivers by the (pre-normalized) vector field's
+        magnitude. Note: only quivers will be affected by this option.
+
     params : dict
         A dictionary mapping symbols to parameters. This keyword argument
         enables the interactive-widgets plot, which doesn't support the
@@ -353,6 +379,23 @@ def plot_vector(*args, **kwargs):
         plotting function to customize the appearance. Refer to the plotting
         library (backend) manual for more informations.
 
+    rendering_kw : list of dicts, optional
+        A list of dictionaries of keywords/values which is passed to the
+        backend's functions to customize the appearance.
+
+        The number of dictionaries must be equal to the number of series
+        generated by the plotting function. For example:
+
+        * if a scalar field and a quiver (or streamline) are shown
+          simultaneously, then two dictionaries must be provided;
+        * if only a quiver (or streamline) is shown, then one dictionary must
+          be provided.
+        * if two or more quivers (or streamlines) are shown, then two or more
+          dictionaries must be provided.
+
+        Note that this will override ``quiver_kw``, ``stream_kw``,
+        ``contour_kw``.
+
     scalar : boolean, Expr, None or list/tuple of 2 elements
         Represents the scalar field to be plotted in the background of a 2D
         vector field plot. Can be:
@@ -361,9 +404,10 @@ def plot_vector(*args, **kwargs):
           single vector field is plotted.
         - `False`/`None`: do not plot any scalar field.
         - `Expr`: a symbolic expression representing the scalar field.
-        - `list`/`tuple`: [scalar_expr, label], where the label will be
-          shown on the colorbar.
         - a numerical function of 2 variables supporting vectorization.
+        - `list`/`tuple`: [scalar_expr, label], where the label will be
+          shown on the colorbar. scalar_expr can be a symbolic expression
+          or a numerical function of 2 variables supporting vectorization.
 
         Default to True.
 
@@ -456,7 +500,7 @@ def plot_vector(*args, **kwargs):
        :format: doctest
        :include-source: True
 
-       >>> from sympy import symbols, sin, cos, Plane, Matrix, sqrt
+       >>> from sympy import symbols, sin, cos, Plane, Matrix, sqrt, latex
        >>> from spb.vectors import plot_vector
        >>> x, y, z = symbols('x, y, z')
 
@@ -468,41 +512,69 @@ def plot_vector(*args, **kwargs):
        :format: doctest
        :include-source: True
 
-       >>> plot_vector([-sin(y), cos(x)], (x, -3, 3), (y, -3, 3),
-       ...     quiver_kw=dict(color="black"),
-       ...     contour_kw={"cmap": "Blues_r", "levels": 20},
+       >>> v = [sin(x - y), cos(x + y)]
+       >>> plot_vector(v, (x, -3, 3), (y, -3, 3),
+       ...     quiver_kw=dict(color="black", scale=30, headwidth=5),
+       ...     contour_kw={"cmap": "Blues_r", "levels": 15},
        ...     grid=False, xlabel="x", ylabel="y")
        Plot object containing:
-       [0]: contour: sqrt(sin(y)**2 + cos(x)**2) for x over (-3.0, 3.0) and y over (-3.0, 3.0)
-       [1]: 2D vector series: [-sin(y), cos(x)] over (x, -3.0, 3.0), (y, -3.0, 3.0)
+       [0]: contour: sqrt(sin(x - y)**2 + cos(x + y)**2) for x over (-3.0, 3.0) and y over (-3.0, 3.0)
+       [1]: 2D vector series: [sin(x - y), cos(x + y)] over (x, -3.0, 3.0), (y, -3.0, 3.0)
 
-    Streamlines plot of a 2D vector field with no background scalar field and
-    custom label:
+    Quivers plot of a 2D vector field with no background scalar field,
+    a custom label and normalized quiver lengths:
 
     .. plot::
        :context: close-figs
        :format: doctest
        :include-source: True
 
-       >>> expr = [-sin(y), cos(x)]
-       >>> plot_vector(expr, (x, -3, 3), (y, -3, 3),
-       ...     streamlines=True, scalar=None,
-       ...     label="Magnitude of %s" % str(expr), xlabel="x", ylabel="y")
+       >>> plot_vector(
+       ...     v, (x, -3, 3), (y, -3, 3),
+       ...     label="Magnitude of $%s$" % latex([-sin(y), cos(x)]),
+       ...     scalar=False, normalize=True,
+       ...     quiver_kw={
+       ...         "scale": 35, "headwidth": 4, "cmap": "gray",
+       ...         "clim": [0, 1.6]},
+       ...     grid=False, xlabel="x", ylabel="y")
        Plot object containing:
-       [0]: 2D vector series: [-sin(y), cos(x)] over (x, -3.0, 3.0), (y, -3.0, 3.0)
+       [0]: contour: sqrt(sin(x - y)**2 + cos(x + y)**2) for x over (-3.0, 3.0) and y over (-3.0, 3.0)
+       [1]: 2D vector series: [sin(x - y), cos(x + y)] over (x, -3.0, 3.0), (y, -3.0, 3.0)
+
+    Streamlines plot of a 2D vector field with no background scalar field, and
+    a custom label:
+
+    .. plot::
+       :context: close-figs
+       :format: doctest
+       :include-source: True
+
+       >>> plot_vector(v, (x, -3, 3), (y, -3, 3),
+       ...     streamlines=True, scalar=None,
+       ...     stream_kw={"density": 1.5},
+       ...     label="Magnitude of %s" % str(v), xlabel="x", ylabel="y")
+       Plot object containing:
+       [0]: 2D vector series: [sin(x - y), cos(x + y)] over (x, -3.0, 3.0), (y, -3.0, 3.0)
 
 
     Plot multiple 2D vectors fields, setting a background scalar field to be
-    the magnitude of the first vector.
+    the magnitude of the first vector. Also, apply custom rendering options
+    to all data series.
 
     .. plot::
        :context: close-figs
        :format: doctest
        :include-source: True
 
-       >>> plot_vector([-sin(y), cos(x)], [y, x], (x, -5, 5), (y, -3, 3), n=20,
-       ...     scalar=sqrt((-sin(y))**2 + cos(x)**2), legend=True, grid=False,
-       ...     xlabel="x", ylabel="y")
+       >>> scalar_expr = sqrt((-sin(y))**2 + cos(x)**2)
+       >>> plot_vector([-sin(y), cos(x)], [2 * y, x], (x, -5, 5), (y, -3, 3),
+       ...     n=20, legend=True, grid=False, xlabel="x", ylabel="y",
+       ...     scalar=[scalar_expr, "$%s$" % latex(scalar_expr)],
+       ...     rendering_kw=[
+       ...         {"cmap": "summer"}, # to the contour
+       ...         {"color": "k"},     # to the first quiver
+       ...         {"color": "w"}      # to the second quiver
+       ... ])
        Plot object containing:
        [0]: contour: sqrt(sin(y)**2 + cos(x)**2) for x over (-5.0, 5.0) and y over (-3.0, 3.0)
        [1]: 2D vector series: [-sin(y), cos(x)] over (x, -5.0, 5.0), (y, -3.0, 3.0)
@@ -521,73 +593,151 @@ def plot_vector(*args, **kwargs):
        >>> fx = lambda x, y: np.cos(f(x, y))
        >>> fy = lambda x, y: np.sin(f(x, y))
        >>> plot_vector([fx, fy], ("x", -1, 1), ("y", -1, 1),
-       ...     streamlines=True, scalar=False)
+       ...     streamlines=True, scalar=False, use_cm=False)
 
     Interactive-widget 2D vector plot. Refer to ``iplot`` documentation to
     learn more about the ``params`` dictionary.
 
-    .. code-block:: python
+    .. panel-screenshot::
+       :small-size: 800, 600
 
        from sympy import *
        from spb import *
-       x, y, u = symbols("x y u")
+       x, y, a, b = symbols("x, y, a, b")
+       v = [-sin(a * y), cos(b * x)]
        plot_vector(
-           [-sin(u * y), cos(x)], (x, -3, 3), (y, -3, 3),
-           params={u: (1, 0, 2)},
-           n=20,
-           quiver_kw=dict(color="black"),
-           contour_kw={"cmap": "Blues_r", "levels": 20},
-           grid=False, xlabel="x", ylabel="y")
+           v, (x, -3, 3), (y, -3, 3),
+           params={a: (1, -2, 2), b: (1, -2, 2)},
+           quiver_kw=dict(color="black", scale=30, headwidth=5),
+           contour_kw={"cmap": "Blues_r", "levels": 15},
+           grid=False, xlabel="x", ylabel="y", use_latex=False)
 
     3D vector field.
 
-    .. plot::
-       :context: close-figs
-       :format: doctest
-       :include-source: True
+    .. k3d-screenshot::
 
-       >>> plot_vector([z, y, x], (x, -10, 10), (y, -10, 10), (z, -10, 10),
-       ...      label="Magnitude", n=8, quiver_kw={"length": 0.1},
-       ...      xlabel="x", ylabel="y", zlabel="z")
-       Plot object containing:
-       [0]: 3D vector series: [z, y, x] over (x, -10.0, 10.0), (y, -10.0, 10.0), (z, -10.0, 10.0)
+       from sympy import *
+       from spb import *
+       var("x:z")
+       plot_vector([z, y, x], (x, -10, 10), (y, -10, 10), (z, -10, 10),
+           backend=KB, n=8, xlabel="x", ylabel="y", zlabel="z",
+           quiver_kw={"scale": 0.5, "line_width": 0.1, "head_size": 10})
 
     3D vector field with 3 orthogonal slice planes.
 
-    .. plot::
-       :context: close-figs
-       :format: doctest
-       :include-source: True
+    .. k3d-screenshot::
+       :camera: 18.45, -25.63, 14.10, 0.45, -1.02, -2.32, -0.25, 0.35, 0.9
 
-       >>> plot_vector([z, y, x], (x, -10, 10), (y, -10, 10), (z, -10, 10),
-       ...      n=8, quiver_kw={"length": 0.1},
-       ...      slice=[
-       ...          Plane((-10, 0, 0), (1, 0, 0)),
-       ...          Plane((0, 10, 0), (0, 2, 0)),
-       ...          Plane((0, 0, -10), (0, 0, 1))],
-       ...      label=["Magnitude"] * 3, xlabel="x", ylabel="y", zlabel="z")
-       Plot object containing:
-       [0]: sliced 3D vector series: [z, y, x] over (x, -10.0, 10.0), (y, -10.0, 10.0), (z, -10.0, 10.0) at Plane(Point3D(-10, 0, 0), (1, 0, 0))
-       [1]: sliced 3D vector series: [z, y, x] over (x, -10.0, 10.0), (y, -10.0, 10.0), (z, -10.0, 10.0) at Plane(Point3D(0, 10, 0), (0, 2, 0))
-       [2]: sliced 3D vector series: [z, y, x] over (x, -10.0, 10.0), (y, -10.0, 10.0), (z, -10.0, 10.0) at Plane(Point3D(0, 0, -10), (0, 0, 1))
+       from sympy import *
+       from spb import *
+       var("x:z")
+       plot_vector([z, y, x], (x, -10, 10), (y, -10, 10), (z, -10, 10),
+           backend=KB, n=8, use_cm=False, grid=False,
+           xlabel="x", ylabel="y", zlabel="z",
+           quiver_kw={"scale": 0.25, "line_width": 0.1, "head_size": 10},
+           slice=[
+               Plane((-10, 0, 0), (1, 0, 0)),
+               Plane((0, 10, 0), (0, 2, 0)),
+               Plane((0, 0, -10), (0, 0, 1))])
 
-    3D vector streamlines starting at a 1000 random points:
+    3D vector streamlines starting at a 300 random points:
 
-    .. plot::
-       :context: close-figs
-       :format: doctest
-       :include-source: True
+    .. k3d-screenshot::
+       :camera: 3.7, -8.16, 2.8, -0.75, -0.51, -0.63, -0.16, 0.27, 0.96
 
-       >>> plot_vector(
-       ...     Matrix([z, y, x]), (x, -10, 10), (y, -10, 10), (z, -10, 10),
-       ...     streamlines=True,
-       ...     stream_kw=dict(
-       ...         starts=True,
-       ...         npoints=1000
-       ...     ),
-       ...     label="Magnitude", xlabel="x", ylabel="y", zlabel="z")
-       Plot object containing:
-       [0]: 3D vector series: [z, y, x] over (x, -10.0, 10.0), (y, -10.0, 10.0), (z, -10.0, 10.0)
+       from sympy import *
+       from spb import *
+       import k3d
+       var("x:z")
+       plot_vector(Matrix([z, -x, y]), (x, -3, 3), (y, -3, 3), (z, -3, 3),
+           backend=KB, n=40, streamlines=True,
+           stream_kw=dict(
+               starts=True,
+               npoints=400,
+               width=0.025,
+               color_map=k3d.colormaps.matplotlib_color_maps.viridis
+           ),
+           xlabel="x", ylabel="y", zlabel="z")
+
+    3D vector streamlines starting at the XY plane. Note that the number of
+    discretization points of the plane controls the numbers of streamlines.
+
+    .. k3d-screenshot::
+       :camera: -2.64, -22.6, 8.8, 0.03, -0.6, -1.13, 0.1, 0.35, 0.93
+
+       from sympy import *
+       from spb import *
+       import k3d
+       var("x:z")
+       u = -y - z
+       v = x + y / 5
+       w = S(1) / 5 + (x - S(5) / 2) * z
+       s = 10 # length of the cubic discretization volume
+       # create an XY plane with n discretization points along each direction
+       n = 8
+       p1 = plot_geometry(
+           Plane((0, 0, 0), (0, 0, 1)), (x, -s, s), (y, -s, s), (z, -s, s),
+           n1=n, n2=n, show=False)
+       # extract the coordinates of the starting points for the streamlines
+       xx, yy, zz = p1[0].get_data()
+       # streamlines plot
+       plot_vector(Matrix([u, v, w]), (x, -s, s), (y, -s, s), (z, -s, s),
+           backend=KB, n=40, streamlines=True, grid=False,
+           stream_kw=dict(
+               starts=dict(x=xx, y=yy, z=zz),
+               npoints=200,
+               width=0.025,
+               color_map=k3d.colormaps.matplotlib_color_maps.plasma
+           ),
+           title="Rössler \, attractor", xlabel="x", ylabel="y", zlabel="z")
+
+    Visually verify the normal vector to a circular cone surface.
+    The following steps are executed:
+
+    1. compute the normal vector to a circular cone surface. This will be the
+       vector field to be plotted.
+    2. plot the cone surface for visualization purposes (use high number of
+       discretization points).
+    3. plot the cone surface that will be used to slice the vector field (use
+       a low number of discretization points). The data series associated to
+       this plot will be used in the ``slice`` keyword argument in the next
+       step.
+    4. plot the sliced vector field.
+    5. combine the plots of step 4 and 2 to get a nice visualization.
+
+    .. k3d-screenshot::
+       :camera: 4.5, -3.9, 2, 1.3, 0.04, -0.36, -0.25, 0.27, 0.93
+
+       from sympy import tan, cos, sin, pi, symbols
+       from spb import plot3d_parametric_surface, plot_vector, KB
+       from sympy.vector import CoordSys3D, gradient
+
+       u, v = symbols("u, v")
+       N = CoordSys3D("N")
+       i, j, k = N.base_vectors()
+       xn, yn, zn = N.base_scalars()
+
+       t = 0.35    # half-cone angle in radians
+       expr = -xn**2 * tan(t)**2 + yn**2 + zn**2    # cone surface equation
+       g = gradient(expr)
+       n = g / g.magnitude()    # unit normal vector
+       n1, n2 = 10, 20 # number of discretization points for the vector field
+
+       # cone surface for visualization (high number of discretization points)
+       p1 = plot3d_parametric_surface(
+           u / tan(t), u * cos(v), u * sin(v), (u, 0, 1), (v, 0 , 2*pi),
+           {"opacity": 1}, backend=KB, show=False, wireframe=True,
+           wf_n1=n1, wf_n2=n2, wf_rendering_kw={"width": 0.004})
+       # cone surface to discretize vector field (low numb of discret points)
+       p2 = plot3d_parametric_surface(
+           u / tan(t), u * cos(v), u * sin(v), (u, 0, 1), (v, 0 , 2*pi),
+           n1=n1, n2=n2, show=False)
+       # plot vector field on over the surface of the cone
+       p3 = plot_vector(
+           n, (xn, -5, 5), (yn, -5, 5), (zn, -5, 5), slice=p2[0],
+           backend=KB, use_cm=False, show=False,
+           quiver_kw={"scale": 0.5, "pivot": "tail"})
+       (p1 + p3).show()
 
     See Also
     ========
@@ -598,8 +748,6 @@ def plot_vector(*args, **kwargs):
     args = _plot_sympify(args)
     args = _preprocess(*args)
 
-    labels = kwargs.pop("label", [])
-    rendering_kw = kwargs.pop("rendering_kw", None)
     kwargs = _set_discretization_points(kwargs, Vector3DSeries)
     kwargs.setdefault("aspect", "equal")
     kwargs.setdefault("legend", True)
@@ -612,6 +760,9 @@ def plot_vector(*args, **kwargs):
         kwargs["is_vector"] = True
         return iplot(*args, **kwargs)
 
+    labels = kwargs.pop("label", [])
+    rendering_kw = kwargs.pop("rendering_kw", None)
+
     series = _build_series(*args, **kwargs)
     if all([isinstance(s, (Vector2DSeries, ContourSeries)) for s in series]):
         Backend = kwargs.pop("backend", TWO_D_B)
